@@ -19,6 +19,21 @@
 
 package org.apache.dolphinscheduler.alert.api;
 
+import lombok.NonNull;
+
+/**
+ * alert channel for sending alerts
+ */
 public interface AlertChannel {
+    /**
+     * process and send alert
+     *
+     * @param info alert info
+     * @return process alarm result
+     */
     AlertResult process(AlertInfo info);
+
+    default @NonNull AlertResult closeAlert(AlertInfo info) {
+        return new AlertResult("true", "no need to close alert");
+    }
 }
