@@ -18,7 +18,7 @@
 package org.apache.dolphinscheduler.plugin.alert.dingtalk;
 
 import org.apache.dolphinscheduler.alert.api.AlertResult;
-import org.apache.dolphinscheduler.spi.utils.JSONUtils;
+import org.apache.dolphinscheduler.common.utils.JSONUtils;
 
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.codec.binary.StringUtils;
@@ -171,7 +171,8 @@ public final class DingTalkSender {
 
         String msg = generateMsgJson(title, content);
 
-        HttpPost httpPost = constructHttpPost(org.apache.dolphinscheduler.spi.utils.StringUtils.isBlank(secret) ? url : generateSignedUrl(), msg);
+        HttpPost httpPost = constructHttpPost(
+                org.apache.commons.lang3.StringUtils.isBlank(secret) ? url : generateSignedUrl(), msg);
 
         CloseableHttpClient httpClient;
         if (Boolean.TRUE.equals(enableProxy)) {
@@ -207,7 +208,7 @@ public final class DingTalkSender {
      * @return msg
      */
     private String generateMsgJson(String title, String content) {
-        if (org.apache.dolphinscheduler.spi.utils.StringUtils.isBlank(msgType)) {
+        if (org.apache.commons.lang3.StringUtils.isBlank(msgType)) {
             msgType = DingTalkParamsConstants.DING_TALK_MSG_TYPE_TEXT;
         }
         Map<String, Object> items = new HashMap<>();
@@ -237,7 +238,7 @@ public final class DingTalkSender {
         StringBuilder builder = new StringBuilder(title);
         builder.append("\n");
         builder.append(content);
-        if (org.apache.dolphinscheduler.spi.utils.StringUtils.isNotBlank(keyword)) {
+        if (org.apache.commons.lang3.StringUtils.isNotBlank(keyword)) {
             builder.append(" ");
             builder.append(keyword);
         }
@@ -255,19 +256,19 @@ public final class DingTalkSender {
      */
     private void generateMarkdownMsg(String title, String content, Map<String, Object> text) {
         StringBuilder builder = new StringBuilder(content);
-        if (org.apache.dolphinscheduler.spi.utils.StringUtils.isNotBlank(keyword)) {
+        if (org.apache.commons.lang3.StringUtils.isNotBlank(keyword)) {
             builder.append(" ");
             builder.append(keyword);
         }
         builder.append("\n\n");
-        if (org.apache.dolphinscheduler.spi.utils.StringUtils.isNotBlank(atMobiles)) {
+        if (org.apache.commons.lang3.StringUtils.isNotBlank(atMobiles)) {
             Arrays.stream(atMobiles.split(",")).forEach(value -> {
                 builder.append("@");
                 builder.append(value);
                 builder.append(" ");
             });
         }
-        if (org.apache.dolphinscheduler.spi.utils.StringUtils.isNotBlank(atUserIds)) {
+        if (org.apache.commons.lang3.StringUtils.isNotBlank(atUserIds)) {
             Arrays.stream(atUserIds.split(",")).forEach(value -> {
                 builder.append("@");
                 builder.append(value);
@@ -289,8 +290,12 @@ public final class DingTalkSender {
     private void setMsgAt(Map<String, Object> items) {
         Map<String, Object> at = new HashMap<>();
 
-        String[] atMobileArray = org.apache.dolphinscheduler.spi.utils.StringUtils.isNotBlank(atMobiles) ? atMobiles.split(",") : new String[0];
-        String[] atUserArray = org.apache.dolphinscheduler.spi.utils.StringUtils.isNotBlank(atUserIds) ? atUserIds.split(",") : new String[0];
+        String[] atMobileArray =
+                org.apache.commons.lang3.StringUtils.isNotBlank(atMobiles) ? atMobiles.split(",")
+                        : new String[0];
+        String[] atUserArray =
+                org.apache.commons.lang3.StringUtils.isNotBlank(atUserIds) ? atUserIds.split(",")
+                        : new String[0];
         boolean isAtAll = Objects.isNull(atAll) ? false : atAll;
 
         at.put("atMobiles", atMobileArray);
@@ -308,7 +313,7 @@ public final class DingTalkSender {
     private String generateSignedUrl() {
         Long timestamp = System.currentTimeMillis();
         String stringToSign = timestamp + "\n" + secret;
-        String sign = org.apache.dolphinscheduler.spi.utils.StringUtils.EMPTY;
+        String sign = org.apache.commons.lang3.StringUtils.EMPTY;
         try {
             Mac mac = Mac.getInstance("HmacSHA256");
             mac.init(new SecretKeySpec(secret.getBytes("UTF-8"), "HmacSHA256"));
