@@ -22,6 +22,8 @@ import org.apache.dolphinscheduler.alert.api.AlertData;
 import org.apache.dolphinscheduler.alert.api.AlertInfo;
 import org.apache.dolphinscheduler.alert.api.AlertResult;
 
+import org.apache.commons.collections.MapUtils;
+
 import java.util.Map;
 
 public final class ScriptAlertChannel implements AlertChannel {
@@ -29,7 +31,7 @@ public final class ScriptAlertChannel implements AlertChannel {
     public AlertResult process(AlertInfo alertinfo) {
         AlertData alertData = alertinfo.getAlertData();
         Map<String, String> paramsMap = alertinfo.getAlertParams();
-        if (paramsMap == null || paramsMap.isEmpty()) {
+        if (MapUtils.isEmpty(paramsMap)) {
             return new AlertResult("false", "script params is empty");
         }
         return new ScriptSender(paramsMap).sendScriptAlert(alertData.getTitle(), alertData.getContent());
