@@ -25,6 +25,7 @@ import java.util.Map;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
 
 /**
  * ScriptSenderTest
@@ -53,13 +54,21 @@ public class ScriptSenderTest {
         Assert.assertEquals("false", alertResult.getStatus());
     }
 
+    @Test
+    public void testScriptSenderInjectionTest() {
+        scriptConfig.put(ScriptParamsConstants.NAME_SCRIPT_USER_PARAMS, "' ; calc.exe ; '");
+        ScriptSender scriptSender = new ScriptSender(scriptConfig);
+        AlertResult alertResult = scriptSender.sendScriptAlert("test title Kris", "test content");
+        Assert.assertEquals("false", alertResult.getStatus());
+    }
+
     @Test
     public void testUserParamsNPE() {
         scriptConfig.put(ScriptParamsConstants.NAME_SCRIPT_USER_PARAMS, null);
         ScriptSender scriptSender = new ScriptSender(scriptConfig);
         AlertResult alertResult;
         alertResult = scriptSender.sendScriptAlert("test user params NPE", "test content");
-        Assert.assertEquals("true", alertResult.getStatus());
+        Assertions.assertEquals("true", alertResult.getStatus());
     }
 
     @Test
@@ -68,7 +77,7 @@ public class ScriptSenderTest {
         ScriptSender scriptSender = new ScriptSender(scriptConfig);
         AlertResult alertResult;
         alertResult = scriptSender.sendScriptAlert("test path NPE", "test content");
-        Assert.assertEquals("false", alertResult.getStatus());
+        Assertions.assertEquals("false", alertResult.getStatus());
     }
 
     @Test
@@ -77,15 +86,7 @@ public class ScriptSenderTest {
         ScriptSender scriptSender = new ScriptSender(scriptConfig);
         AlertResult alertResult;
         alertResult = scriptSender.sendScriptAlert("test type is error", "test content");
-        Assert.assertEquals("false", alertResult.getStatus());
-    }
-
-    @Test
-    public void testScriptSenderInjectionTest() {
-        scriptConfig.put(ScriptParamsConstants.NAME_SCRIPT_USER_PARAMS, "' ; calc.exe ; '");
-        ScriptSender scriptSender = new ScriptSender(scriptConfig);
-        AlertResult alertResult = scriptSender.sendScriptAlert("test title Kris", "test content");
-        Assert.assertEquals("false", alertResult.getStatus());
+        Assertions.assertEquals("false", alertResult.getStatus());
     }
 
 }
