@@ -17,11 +17,14 @@
 
 package org.apache.dolphinscheduler.api.service;
 
+import java.util.List;
+import java.util.Map;
+
 import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.utils.Result;
+import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.dao.entity.User;
-
-import java.util.Map;
+import org.slf4j.Logger;
 
 /**
  * base service
@@ -36,6 +39,7 @@ public interface BaseService {
      */
     boolean isAdmin(User user);
 
+
     /**
      * isNotAdmin
      *
@@ -45,6 +49,15 @@ public interface BaseService {
      */
     boolean isNotAdmin(User loginUser, Map<String, Object> result);
 
+    /**
+     * permissionPostHandle
+     * @param authorizationType
+     * @param userId
+     * @param ids
+     * @param logger
+     */
+    void permissionPostHandle(AuthorizationType authorizationType, Integer userId, List<Integer> ids, Logger logger);
+
     /**
      * put message to map
      *
@@ -83,6 +96,16 @@ public interface BaseService {
      */
     boolean canOperator(User operateUser, int createUserId);
 
+    /**
+     * Verify that the operator has permissions
+     * @param user operate user
+     * @param ids Object[]
+     * @Param type authorizationType
+     * @Param perm String
+     * @return check result
+     */
+    boolean canOperatorPermissions(User user, Object[] ids, AuthorizationType type, String perm);
+
     /**
      * check and parse date parameters
      *
@@ -91,4 +114,13 @@ public interface BaseService {
      * @return map<status,startDate,endDate>
      */
     Map<String, Object> checkAndParseDateParameters(String startDateStr, String endDateStr);
+
+    /**
+     * check checkDescriptionLength
+     *
+     * @param description input String
+     * @return ture if Length acceptable, Length exceeds return false
+     */
+    boolean checkDescriptionLength(String description);
+
 }
