@@ -1,3 +1,4 @@
+
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -17,11 +18,18 @@
 
 package org.apache.dolphinscheduler.api.service;
 
+import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.PROJECT;
+import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.PROJECT_CREATE;
+import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.PROJECT_DELETE;
+import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.PROJECT_UPDATE;
+
 import org.apache.dolphinscheduler.api.enums.Status;
+import org.apache.dolphinscheduler.api.permission.ResourcePermissionCheckService;
+import org.apache.dolphinscheduler.api.service.impl.BaseServiceImpl;
 import org.apache.dolphinscheduler.api.service.impl.ProjectServiceImpl;
-import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.api.utils.Result;
-import org.apache.dolphinscheduler.common.Constants;
+import org.apache.dolphinscheduler.common.constants.Constants;
+import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.UserType;
 import org.apache.dolphinscheduler.dao.entity.ProcessDefinition;
 import org.apache.dolphinscheduler.dao.entity.Project;
@@ -37,8 +45,10 @@ import org.apache.commons.collections.CollectionUtils;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -50,9 +60,6 @@ import org.mockito.junit.MockitoJUnitRunner;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.baomidou.mybatisplus.core.metadata.IPage;
-import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
-
 /**
  * project service test
  **/
@@ -60,7 +67,8 @@ import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 public class ProjectServiceTest {
 
     private static final Logger logger = LoggerFactory.getLogger(ProjectServiceTest.class);
-
+    private static final Logger baseServiceLogger = LoggerFactory.getLogger(BaseServiceImpl.class);
+    private static final Logger projectLogger = LoggerFactory.getLogger(ProjectServiceImpl.class);
     @InjectMocks
     private ProjectServiceImpl projectService;
 
@@ -76,6 +84,9 @@ public class ProjectServiceTest {
     @Mock
     private UserMapper userMapper;
 
+    @Mock
+    private ResourcePermissionCheckService resourcePermissionCheckService;
+
     private String projectName = "ProjectServiceTest";
 
     private String userName = "ProjectServiceTest";
@@ -85,21 +96,25 @@ public class ProjectServiceTest {
 
         User loginUser = getLoginUser();
         loginUser.setId(1);
-        Map<String, Object> result = projectService.createProject(loginUser, projectName, getDesc());
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.PROJECTS, null, 1,
+                PROJECT_CREATE, baseServiceLogger)).thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.PROJECTS, null, 1,
+                baseServiceLogger)).thenReturn(true);
+        Result result = projectService.createProject(loginUser, projectName, getDesc());
         logger.info(result.toString());
-        Assert.assertEquals(Status.REQUEST_PARAMS_NOT_VALID_ERROR, result.get(Constants.STATUS));
+        Assert.assertEquals(Status.REQUEST_PARAMS_NOT_VALID_ERROR.getCode(), 10001);
 
-        //project name exist
+        // project name exist
         Mockito.when(projectMapper.queryByName(projectName)).thenReturn(getProject());
         result = projectService.createProject(loginUser, projectName, projectName);
         logger.info(result.toString());
-        Assert.assertEquals(Status.PROJECT_ALREADY_EXISTS, result.get(Constants.STATUS));
+        Assert.assertEquals(Status.PROJECT_ALREADY_EXISTS.getCode(), result.getCode().intValue());
 
-        //success
+        // success
         Mockito.when(projectMapper.insert(Mockito.any(Project.class))).thenReturn(1);
         result = projectService.createProject(loginUser, "test", "test");
         logger.info(result.toString());
-        Assert.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        Assert.assertEquals(Status.SUCCESS.getCode(), result.getCode().intValue());
 
     }
 
@@ -107,41 +122,51 @@ public class ProjectServiceTest {
     public void testCheckProjectAndAuth() {
 
         long projectCode = 1L;
-        Mockito.when(projectUserMapper.queryProjectRelation(1, 1)).thenReturn(getProjectUser());
         User loginUser = getLoginUser();
 
-        Map<String, Object> result = projectService.checkProjectAndAuth(loginUser, null, projectCode);
+        Map<String, Object> result = projectService.checkProjectAndAuth(loginUser, null, projectCode, PROJECT);
         logger.info(result.toString());
         Status status = (Status) result.get(Constants.STATUS);
         Assert.assertEquals(Status.PROJECT_NOT_EXIST, result.get(Constants.STATUS));
 
         Project project = getProject();
-        //USER_NO_OPERATION_PROJECT_PERM
+        // USER_NO_OPERATION_PROJECT_PERM
         project.setUserId(2);
-        result = projectService.checkProjectAndAuth(loginUser, project, projectCode);
+        result = projectService.checkProjectAndAuth(loginUser, project, projectCode, PROJECT);
         logger.info(result.toString());
         Assert.assertEquals(Status.USER_NO_OPERATION_PROJECT_PERM, result.get(Constants.STATUS));
 
-        //success
+        // success
         project.setUserId(1);
-        result = projectService.checkProjectAndAuth(loginUser, project, projectCode);
+        loginUser.setUserType(UserType.ADMIN_USER);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.PROJECTS,
+                new Object[]{project.getId()},
+                project.getUserId(), PROJECT, baseServiceLogger)).thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.PROJECTS,
+                new Object[]{project.getId()},
+                0, baseServiceLogger)).thenReturn(true);
+        result = projectService.checkProjectAndAuth(loginUser, project, projectCode, PROJECT);
         logger.info(result.toString());
         Assert.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
 
         Map<String, Object> result2 = new HashMap<>();
 
-        result2 = projectService.checkProjectAndAuth(loginUser, null, projectCode);
+        result2 = projectService.checkProjectAndAuth(loginUser, null, projectCode, PROJECT);
         Assert.assertEquals(Status.PROJECT_NOT_EXIST, result2.get(Constants.STATUS));
 
         Project project1 = getProject();
         // USER_NO_OPERATION_PROJECT_PERM
         project1.setUserId(2);
-        result2 = projectService.checkProjectAndAuth(loginUser, project1, projectCode);
+        loginUser.setUserType(UserType.GENERAL_USER);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.PROJECTS,
+                new Object[]{project.getId()},
+                loginUser.getId(), PROJECT, baseServiceLogger)).thenReturn(true);
+        result2 = projectService.checkProjectAndAuth(loginUser, project1, projectCode, PROJECT);
         Assert.assertEquals(Status.USER_NO_OPERATION_PROJECT_PERM, result2.get(Constants.STATUS));
 
-        //success
+        // success
         project1.setUserId(1);
-        projectService.checkProjectAndAuth(loginUser, project1, projectCode);
+        projectService.checkProjectAndAuth(loginUser, project1, projectCode, PROJECT);
 
     }
 
@@ -155,100 +180,105 @@ public class ProjectServiceTest {
         // not exist user
         User tempUser = new User();
         tempUser.setId(Integer.MAX_VALUE);
-        boolean checkResult = projectService.hasProjectAndPerm(tempUser, project, result);
+        tempUser.setUserType(UserType.GENERAL_USER);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.PROJECTS,
+                new Object[]{project.getId()},
+                tempUser.getId(), null, baseServiceLogger)).thenReturn(true);
+        boolean checkResult = projectService.hasProjectAndPerm(tempUser, project, result, null);
         logger.info(result.toString());
         Assert.assertFalse(checkResult);
 
-        //success
+        // success
         result = new HashMap<>();
         project.setUserId(1);
-        checkResult = projectService.hasProjectAndPerm(loginUser, project, result);
+        loginUser.setUserType(UserType.ADMIN_USER);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.PROJECTS,
+                new Object[]{project.getId()},
+                loginUser.getId(), null, baseServiceLogger)).thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.PROJECTS,
+                new Object[]{project.getId()},
+                0, baseServiceLogger)).thenReturn(true);
+        checkResult = projectService.hasProjectAndPerm(loginUser, project, result, null);
         logger.info(result.toString());
         Assert.assertTrue(checkResult);
     }
 
-    @Test
-    public void testQueryProjectListPaging() {
-
-        IPage<Project> page = new Page<>(1, 10);
-        page.setRecords(getList());
-        page.setTotal(1L);
-        Mockito.when(projectMapper.queryProjectListPaging(Mockito.any(Page.class), Mockito.eq(1), Mockito.eq(projectName))).thenReturn(page);
-        User loginUser = getLoginUser();
-
-        // project owner
-        Result result = projectService.queryProjectListPaging(loginUser, 10, 1, projectName);
-        logger.info(result.toString());
-        PageInfo<Project> pageInfo = (PageInfo<Project>) result.getData();
-        Assert.assertTrue(CollectionUtils.isNotEmpty(pageInfo.getTotalList()));
-
-        //admin
-        Mockito.when(projectMapper.queryProjectListPaging(Mockito.any(Page.class), Mockito.eq(0), Mockito.eq(projectName))).thenReturn(page);
-        loginUser.setUserType(UserType.ADMIN_USER);
-        result = projectService.queryProjectListPaging(loginUser, 10, 1, projectName);
-        logger.info(result.toString());
-        pageInfo = (PageInfo<Project>) result.getData();
-        Assert.assertTrue(CollectionUtils.isNotEmpty(pageInfo.getTotalList()));
-    }
-
     @Test
     public void testDeleteProject() {
         User loginUser = getLoginUser();
         Mockito.when(projectMapper.queryByCode(1L)).thenReturn(getProject());
-        //PROJECT_NOT_FOUNT
-        Map<String, Object> result = projectService.deleteProject(loginUser, 11L);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.PROJECTS,
+                new Object[]{1}, loginUser.getId(),
+                PROJECT_DELETE, baseServiceLogger)).thenReturn(true);
+        // PROJECT_NOT_FOUNT
+        Result result = projectService.deleteProject(loginUser, 11L);
         logger.info(result.toString());
-        Assert.assertEquals(Status.PROJECT_NOT_EXIST, result.get(Constants.STATUS));
+        Assert.assertTrue(Status.PROJECT_NOT_EXIST.getCode() == result.getCode());
         loginUser.setId(2);
-        //USER_NO_OPERATION_PROJECT_PERM
+        // USER_NO_OPERATION_PROJECT_PERM
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.PROJECTS, new Object[]{1},
+                loginUser.getId(),
+                baseServiceLogger)).thenReturn(true);
         result = projectService.deleteProject(loginUser, 1L);
         logger.info(result.toString());
-        Assert.assertEquals(Status.USER_NO_OPERATION_PROJECT_PERM, result.get(Constants.STATUS));
+        Assert.assertTrue(Status.USER_NO_OPERATION_PROJECT_PERM.getCode() == result.getCode());
 
-        //DELETE_PROJECT_ERROR_DEFINES_NOT_NULL
+        // DELETE_PROJECT_ERROR_DEFINES_NOT_NULL
         Mockito.when(processDefinitionMapper.queryAllDefinitionList(1L)).thenReturn(getProcessDefinitions());
         loginUser.setUserType(UserType.ADMIN_USER);
+        loginUser.setId(1);
+        Mockito.when(
+                resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.PROJECTS, new Object[]{1}, 0,
+                        baseServiceLogger))
+                .thenReturn(true);
         result = projectService.deleteProject(loginUser, 1L);
         logger.info(result.toString());
-        Assert.assertEquals(Status.DELETE_PROJECT_ERROR_DEFINES_NOT_NULL, result.get(Constants.STATUS));
+        Assert.assertTrue(Status.DELETE_PROJECT_ERROR_DEFINES_NOT_NULL.getCode() == result.getCode());
 
-        //success
+        // success
         Mockito.when(projectMapper.deleteById(1)).thenReturn(1);
         Mockito.when(processDefinitionMapper.queryAllDefinitionList(1L)).thenReturn(new ArrayList<>());
         result = projectService.deleteProject(loginUser, 1L);
         logger.info(result.toString());
-        Assert.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        Assert.assertTrue(Status.SUCCESS.getCode() == result.getCode());
     }
 
     @Test
     public void testUpdate() {
 
         User loginUser = getLoginUser();
+        loginUser.setId(1);
         Project project = getProject();
         project.setCode(2L);
+        Mockito.when(resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.PROJECTS,
+                new Object[]{1}, loginUser.getId(),
+                PROJECT_UPDATE, baseServiceLogger)).thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.PROJECTS, new Object[]{1},
+                loginUser.getId(),
+                baseServiceLogger)).thenReturn(true);
         Mockito.when(projectMapper.queryByName(projectName)).thenReturn(project);
         Mockito.when(projectMapper.queryByCode(2L)).thenReturn(getProject());
         // PROJECT_NOT_FOUNT
-        Map<String, Object> result = projectService.update(loginUser, 1L, projectName, "desc", "testUser");
+        Result result = projectService.update(loginUser, 1L, projectName, "desc", "testUser");
         logger.info(result.toString());
-        Assert.assertEquals(Status.PROJECT_NOT_FOUND, result.get(Constants.STATUS));
+        Assert.assertTrue(Status.PROJECT_NOT_FOUND.getCode() == result.getCode());
 
-        //PROJECT_ALREADY_EXISTS
+        // PROJECT_ALREADY_EXISTS
         result = projectService.update(loginUser, 2L, projectName, "desc", userName);
         logger.info(result.toString());
-        Assert.assertEquals(Status.PROJECT_ALREADY_EXISTS, result.get(Constants.STATUS));
+        Assert.assertTrue(Status.PROJECT_ALREADY_EXISTS.getCode() == result.getCode());
 
         Mockito.when(userMapper.queryByUserNameAccurately(Mockito.any())).thenReturn(null);
         result = projectService.update(loginUser, 2L, "test", "desc", "testuser");
-        Assert.assertEquals(Status.USER_NOT_EXIST, result.get(Constants.STATUS));
+        Assert.assertTrue(Status.USER_NOT_EXIST.getCode() == result.getCode());
 
-        //success
+        // success
         Mockito.when(userMapper.queryByUserNameAccurately(Mockito.any())).thenReturn(new User());
         project.setUserId(1);
         Mockito.when(projectMapper.updateById(Mockito.any(Project.class))).thenReturn(1);
         result = projectService.update(loginUser, 2L, "test", "desc", "testUser");
         logger.info(result.toString());
-        Assert.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
+        Assert.assertTrue(Status.SUCCESS.getCode() == result.getCode());
 
     }
 
@@ -260,16 +290,16 @@ public class ProjectServiceTest {
 
         // test admin user
         loginUser.setUserType(UserType.ADMIN_USER);
-        Map<String, Object> result = projectService.queryAuthorizedProject(loginUser, 2);
+        Result result = projectService.queryAuthorizedProject(loginUser, 2);
         logger.info(result.toString());
-        List<Project> projects = (List<Project>) result.get(Constants.DATA_LIST);
+        List<Project> projects = (List<Project>) result.getData();
         Assert.assertTrue(CollectionUtils.isNotEmpty(projects));
 
         // test non-admin user
         loginUser.setUserType(UserType.GENERAL_USER);
         loginUser.setId(3);
         result = projectService.queryAuthorizedProject(loginUser, 2);
-        projects = (List<Project>) result.get(Constants.DATA_LIST);
+        projects = (List<Project>) result.getData();
         Assert.assertTrue(CollectionUtils.isNotEmpty(projects));
     }
 
@@ -278,30 +308,42 @@ public class ProjectServiceTest {
         final User loginUser = this.getLoginUser();
 
         // Failure 1: PROJECT_NOT_FOUND
-        Map<String, Object> result = this.projectService.queryAuthorizedUser(loginUser, 3682329499136L);
+        Result result = this.projectService.queryAuthorizedUser(loginUser, 3682329499136L);
         logger.info("FAILURE 1: {}", result.toString());
-        Assert.assertEquals(Status.PROJECT_NOT_FOUND, result.get(Constants.STATUS));
+        Assert.assertTrue(Status.PROJECT_NOT_FOUND.getCode() == result.getCode());
 
         // Failure 2: USER_NO_OPERATION_PROJECT_PERM
         loginUser.setId(100);
         Mockito.when(this.projectMapper.queryByCode(Mockito.anyLong())).thenReturn(this.getProject());
         result = this.projectService.queryAuthorizedUser(loginUser, 3682329499136L);
         logger.info("FAILURE 2: {}", result.toString());
-        Assert.assertEquals(Status.USER_NO_OPERATION_PROJECT_PERM, result.get(Constants.STATUS));
+        Assert.assertTrue(Status.USER_NO_OPERATION_PROJECT_PERM.getCode() == result.getCode());
 
         // SUCCESS
         loginUser.setUserType(UserType.ADMIN_USER);
+        Mockito.when(
+                resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.PROJECTS, new Object[]{1},
+                        loginUser.getId(), PROJECT, baseServiceLogger))
+                .thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.PROJECTS, new Object[]{1},
+                0, baseServiceLogger)).thenReturn(true);
         Mockito.when(this.userMapper.queryAuthedUserListByProjectId(1)).thenReturn(this.getUserList());
         result = this.projectService.queryAuthorizedUser(loginUser, 3682329499136L);
         logger.info("SUCCESS 1: {}", result.toString());
-        List<User> users = (List<User>) result.get(Constants.DATA_LIST);
+        List<User> users = (List<User>) result.getData();
         Assert.assertTrue(CollectionUtils.isNotEmpty(users));
 
         loginUser.setId(1);
         loginUser.setUserType(UserType.GENERAL_USER);
+        Mockito.when(
+                resourcePermissionCheckService.operationPermissionCheck(AuthorizationType.PROJECTS, new Object[]{1},
+                        loginUser.getId(), PROJECT, baseServiceLogger))
+                .thenReturn(true);
+        Mockito.when(resourcePermissionCheckService.resourcePermissionCheck(AuthorizationType.PROJECTS, new Object[]{1},
+                1, baseServiceLogger)).thenReturn(true);
         result = this.projectService.queryAuthorizedUser(loginUser, 3682329499136L);
         logger.info("SUCCESS 2: {}", result.toString());
-        users = (List<User>) result.get(Constants.DATA_LIST);
+        users = (List<User>) result.getData();
         Assert.assertTrue(CollectionUtils.isNotEmpty(users));
     }
 
@@ -312,7 +354,7 @@ public class ProjectServiceTest {
 
         Mockito.when(projectMapper.queryProjectCreatedByUser(1)).thenReturn(getList());
 
-        //success
+        // success
         loginUser.setUserType(UserType.ADMIN_USER);
         Map<String, Object> result = projectService.queryProjectCreatedByUser(loginUser);
         logger.info(result.toString());
@@ -324,20 +366,27 @@ public class ProjectServiceTest {
     @Test
     public void testQueryProjectCreatedAndAuthorizedByUser() {
 
-        Map<String, Object> result = null;
+        Result result;
         User loginUser = getLoginUser();
-
+        Set<Integer> set = new HashSet();
+        set.add(1);
+        List<Integer> list = new ArrayList<>(1);
+        list.add(1);
         // not admin user
-        Mockito.when(projectMapper.queryProjectCreatedAndAuthorizedByUserId(1)).thenReturn(getList());
+        Mockito.when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS,
+                loginUser.getId(), projectLogger)).thenReturn(set);
+        Mockito.when(projectMapper.selectBatchIds(set)).thenReturn(getList());
         result = projectService.queryProjectCreatedAndAuthorizedByUser(loginUser);
-        List<Project> notAdminUserResult = (List<Project>) result.get(Constants.DATA_LIST);
+        List<Project> notAdminUserResult = (List<Project>) result.getData();
         Assert.assertTrue(CollectionUtils.isNotEmpty(notAdminUserResult));
 
-        //admin user
+        // admin user
         loginUser.setUserType(UserType.ADMIN_USER);
-        Mockito.when(projectMapper.selectList(null)).thenReturn(getList());
+        Mockito.when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS,
+                loginUser.getId(), projectLogger)).thenReturn(set);
+        Mockito.when(projectMapper.selectBatchIds(set)).thenReturn(getList());
         result = projectService.queryProjectCreatedAndAuthorizedByUser(loginUser);
-        List<Project> projects = (List<Project>) result.get(Constants.DATA_LIST);
+        List<Project> projects = (List<Project>) result.getData();
 
         Assert.assertTrue(CollectionUtils.isNotEmpty(projects));
 
@@ -349,33 +398,54 @@ public class ProjectServiceTest {
 
         User user = new User();
         user.setId(0);
-        Map<String, Object> result = projectService.queryAllProjectList(user);
+        Result result = projectService.queryAllProjectList(user);
         logger.info(result.toString());
-        List<Project> projects = (List<Project>) result.get(Constants.DATA_LIST);
+        List<Project> projects = (List<Project>) result.getData();
+        Assert.assertTrue(CollectionUtils.isNotEmpty(projects));
+
+    }
+    @Test
+    public void queryAllProjectListForDependent() {
+        Mockito.when(projectMapper.queryAllProjectForDependent()).thenReturn(getList());
+
+        Result result = projectService.queryAllProjectListForDependent();
+        logger.info(result.toString());
+        List<Project> projects = (List<Project>) result.getData();
         Assert.assertTrue(CollectionUtils.isNotEmpty(projects));
 
     }
 
     @Test
     public void testQueryUnauthorizedProject() {
-        Mockito.when(projectMapper.queryProjectExceptUserId(2)).thenReturn(getList());
-        Mockito.when(projectMapper.queryProjectCreatedByUser(2)).thenReturn(getList());
-        Mockito.when(projectMapper.queryAuthedProjectListByUserId(2)).thenReturn(getSingleList());
-
+        Set<Integer> set = new HashSet();
+        set.add(1);
         // test admin user
         User loginUser = new User();
         loginUser.setUserType(UserType.ADMIN_USER);
-        Map<String, Object> result = projectService.queryUnauthorizedProject(loginUser, 2);
+        loginUser.setId(1);
+        List<Integer> list = new ArrayList<>(1);
+        list.add(1);
+        Mockito.when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS,
+                loginUser.getId(), projectLogger)).thenReturn(set);
+        Mockito.when(projectMapper.listAuthorizedProjects(
+                loginUser.getUserType().equals(UserType.ADMIN_USER) ? 0 : loginUser.getId(), list))
+                .thenReturn(getList());
+        Result result = projectService.queryUnauthorizedProject(loginUser, 2);
         logger.info(result.toString());
-        List<Project> projects = (List<Project>) result.get(Constants.DATA_LIST);
+        List<Project> projects = (List<Project>) result.getData();
         Assert.assertTrue(CollectionUtils.isNotEmpty(projects));
 
         // test non-admin user
         loginUser.setId(2);
         loginUser.setUserType(UserType.GENERAL_USER);
+        Mockito.when(resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS,
+                loginUser.getId(), projectLogger)).thenReturn(set);
+        Mockito.when(projectMapper.listAuthorizedProjects(
+                loginUser.getUserType().equals(UserType.ADMIN_USER) ? 0 : loginUser.getId(), list))
+                .thenReturn(getList());
         result = projectService.queryUnauthorizedProject(loginUser, 3);
         logger.info(result.toString());
-        projects = (List<Project>) result.get(Constants.DATA_LIST);
+        projects = (List<Project>) result.getData();
         Assert.assertTrue(CollectionUtils.isNotEmpty(projects));
     }
 
@@ -422,6 +492,7 @@ public class ProjectServiceTest {
 
     /**
      * Get general user
+     *
      * @return
      */
     private User getGeneralUser() {
@@ -434,6 +505,7 @@ public class ProjectServiceTest {
 
     /**
      * Get user list
+     *
      * @return
      */
     private List<User> getUserList() {
