@@ -26,6 +26,6 @@ import org.springframework.context.annotation.Configuration;
 
 @Configuration
 @EnableAutoConfiguration
-@MapperScan("org.apache.dolphinscheduler.dao")
+@MapperScan("org.apache.dolphinscheduler.dao.mapper")
 public class DaoConfiguration {
 }
