@@ -17,6 +17,7 @@
 
 package org.apache.dolphinscheduler.dao.mapper;
 
+import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 import org.apache.dolphinscheduler.dao.entity.Tenant;
 
 import org.apache.ibatis.annotations.Param;
@@ -28,6 +29,9 @@ import org.springframework.cache.annotation.Cacheable;
 import com.baomidou.mybatisplus.core.mapper.BaseMapper;
 import com.baomidou.mybatisplus.core.metadata.IPage;
 
+import java.util.ArrayList;
+import java.util.List;
+
 /**
  * tenant mapper interface
  */
@@ -70,7 +74,7 @@ public interface TenantMapper extends BaseMapper<Tenant> {
      * @param searchVal searchVal
      * @return tenant IPage
      */
-    IPage<Tenant> queryTenantPaging(IPage<Tenant> page,
+    IPage<Tenant> queryTenantPaging(IPage<Tenant> page,@Param("ids") List<Integer> ids,
                                     @Param("searchVal") String searchVal);
 
     /**
@@ -80,4 +84,19 @@ public interface TenantMapper extends BaseMapper<Tenant> {
      * @return true if exist else return null
      */
     Boolean existTenant(@Param("tenantCode") String tenantCode);
+
+    /**
+     * queryTenantPagingByIds
+     * @param page
+     * @param ids
+     * @param searchVal
+     * @return
+     */
+    IPage<Tenant> queryTenantPagingByIds(Page<Tenant> page, @Param("ids")List<Integer> ids, @Param("searchVal")String searchVal);
+
+    /**
+     * queryAll
+     * @return
+     */
+    List<Tenant> queryAll();
 }
