@@ -18,7 +18,6 @@
 package org.apache.dolphinscheduler.dao.mapper;
 
 import static java.util.stream.Collectors.toList;
-
 import static org.hamcrest.Matchers.greaterThan;
 import static org.hamcrest.Matchers.greaterThanOrEqualTo;
 import static org.junit.Assert.assertEquals;
@@ -86,7 +85,6 @@ public class DataSourceMapperTest extends BaseDaoTest {
         assertEquals(expectedDataSource, actualDataSource);
     }
 
-
     /**
      * test query
      */
@@ -108,7 +106,6 @@ public class DataSourceMapperTest extends BaseDaoTest {
         assertEquals(expectedDataSource, actualDataSource);
     }
 
-
     /**
      * test delete
      */
@@ -123,8 +120,6 @@ public class DataSourceMapperTest extends BaseDaoTest {
         assertNull(actualDataSource);
     }
 
-
-
     /**
      * test query datasource by type
      */
@@ -142,7 +137,7 @@ public class DataSourceMapperTest extends BaseDaoTest {
         for (DataSource actualDataSource : actualDataSources) {
             DataSource expectedDataSource = datasourceMap.get(actualDataSource.getId());
             if (expectedDataSource != null) {
-                assertEquals(expectedDataSource,actualDataSource);
+                assertEquals(expectedDataSource, actualDataSource);
             }
         }
 
@@ -166,7 +161,7 @@ public class DataSourceMapperTest extends BaseDaoTest {
         for (DataSource actualDataSource : actualDataSources) {
             DataSource expectedDataSource = expectedDataSourceMap.get(actualDataSource.getId());
             if (expectedDataSource != null) {
-                assertEquals(expectedDataSource,actualDataSource);
+                assertEquals(expectedDataSource, actualDataSource);
             }
         }
 
@@ -184,7 +179,7 @@ public class DataSourceMapperTest extends BaseDaoTest {
 
         for (DataSource actualDataSource : actualDataSources) {
             if (expectedDataSource.getId() == actualDataSource.getId()) {
-                assertEquals(expectedDataSource,actualDataSource);
+                assertEquals(expectedDataSource, actualDataSource);
             }
         }
 
@@ -205,7 +200,7 @@ public class DataSourceMapperTest extends BaseDaoTest {
         for (DataSource actualDataSource : actualDataSources) {
             DataSource expectedDataSource = expectedDataSourceMap.get(actualDataSource.getId());
             if (expectedDataSource != null) {
-                assertEquals(expectedDataSource,actualDataSource);
+                assertEquals(expectedDataSource, actualDataSource);
             }
         }
 
@@ -226,7 +221,7 @@ public class DataSourceMapperTest extends BaseDaoTest {
         for (DataSource actualDataSource : actualDataSources) {
             DataSource expectedDataSource = expectedDataSourceMap.get(actualDataSource.getId());
             if (expectedDataSource != null) {
-                assertEquals(expectedDataSource,actualDataSource);
+                assertEquals(expectedDataSource, actualDataSource);
             }
         }
     }
@@ -247,48 +242,51 @@ public class DataSourceMapperTest extends BaseDaoTest {
         for (DataSource actualDataSource : actualDataSources) {
             DataSource expectedDataSource = expectedDataSourceMap.get(actualDataSource.getId());
             if (expectedDataSource != null) {
-                assertEquals(expectedDataSource,actualDataSource);
+                assertEquals(expectedDataSource, actualDataSource);
             }
         }
     }
 
     @Test
     public void testListAuthorizedDataSource() {
-        //create general user
+        // create general user
         User generalUser1 = createGeneralUser("user1");
         User generalUser2 = createGeneralUser("user2");
 
-        //create data source
+        // create data source
         DataSource dataSource = createDataSource(generalUser1.getId(), "ds-1");
         DataSource unauthorizdDataSource = createDataSource(generalUser2.getId(), "ds-2");
 
-        //data source ids
+        // data source ids
         Integer[] dataSourceIds = new Integer[]{dataSource.getId(), unauthorizdDataSource.getId()};
 
-        List<DataSource> authorizedDataSource = dataSourceMapper.listAuthorizedDataSource(generalUser1.getId(), dataSourceIds);
+        List<DataSource> authorizedDataSource =
+                dataSourceMapper.listAuthorizedDataSource(generalUser1.getId(), dataSourceIds);
 
-        assertEquals(generalUser1.getId(), dataSource.getUserId());
-        Assert.assertNotEquals(generalUser1.getId(), unauthorizdDataSource.getUserId());
-        Assert.assertFalse(authorizedDataSource.stream().map(t -> t.getId()).collect(toList()).containsAll(Arrays.asList(dataSourceIds)));
+        assertEquals(generalUser1.getId().intValue(), dataSource.getUserId());
+        Assert.assertNotEquals(generalUser1.getId().intValue(), unauthorizdDataSource.getUserId());
+        Assert.assertFalse(authorizedDataSource.stream().map(t -> t.getId()).collect(toList())
+                .containsAll(Arrays.asList(dataSourceIds)));
 
-        //authorize object unauthorizdDataSource to generalUser1
+        // authorize object unauthorizdDataSource to generalUser1
         createUserDataSource(generalUser1, unauthorizdDataSource);
         authorizedDataSource = dataSourceMapper.listAuthorizedDataSource(generalUser1.getId(), dataSourceIds);
 
-        Assert.assertTrue(authorizedDataSource.stream().map(t -> t.getId()).collect(toList()).containsAll(Arrays.asList(dataSourceIds)));
+        Assert.assertTrue(authorizedDataSource.stream().map(t -> t.getId()).collect(toList())
+                .containsAll(Arrays.asList(dataSourceIds)));
     }
 
     /**
      * create datasource relation
      * @param userId
      */
-    private Map<Integer,DataSource> createDataSourceMap(Integer userId,String name) {
+    private Map<Integer, DataSource> createDataSourceMap(Integer userId, String name) {
 
-        Map<Integer,DataSource> dataSourceMap = new HashMap<>();
+        Map<Integer, DataSource> dataSourceMap = new HashMap<>();
 
         DataSource dataSource = createDataSource(userId, name);
 
-        dataSourceMap.put(dataSource.getId(),dataSource);
+        dataSourceMap.put(dataSource.getId(), dataSource);
 
         DataSource otherDataSource = createDataSource(userId + 1, name + "1");
 
@@ -312,12 +310,12 @@ public class DataSourceMapperTest extends BaseDaoTest {
      * @param count datasource count
      * @return datasource map
      */
-    private Map<Integer,DataSource> createDataSourceMap(Integer count) {
-        Map<Integer,DataSource> dataSourceMap = new HashMap<>();
+    private Map<Integer, DataSource> createDataSourceMap(Integer count) {
+        Map<Integer, DataSource> dataSourceMap = new HashMap<>();
 
         for (int i = 0; i < count; i++) {
             DataSource dataSource = createDataSource("test");
-            dataSourceMap.put(dataSource.getId(),dataSource);
+            dataSourceMap.put(dataSource.getId(), dataSource);
         }
 
         return dataSourceMap;
@@ -328,7 +326,7 @@ public class DataSourceMapperTest extends BaseDaoTest {
      * @return datasource
      */
     private DataSource createDataSource() {
-        return createDataSource(1,"test");
+        return createDataSource(1, "test");
     }
 
     /**
@@ -337,7 +335,7 @@ public class DataSourceMapperTest extends BaseDaoTest {
      * @return datasource
      */
     private DataSource createDataSource(String name) {
-        return createDataSource(1,name);
+        return createDataSource(1, name);
     }
 
     /**
@@ -346,7 +344,7 @@ public class DataSourceMapperTest extends BaseDaoTest {
      * @param name name
      * @return datasource
      */
-    private DataSource createDataSource(Integer userId,String name) {
+    private DataSource createDataSource(Integer userId, String name) {
         Random random = new Random();
         DataSource dataSource = new DataSource();
         dataSource.setUserId(userId);
@@ -399,4 +397,4 @@ public class DataSourceMapperTest extends BaseDaoTest {
         return datasourceUser;
     }
 
-}
\ No newline at end of file
+}
