@@ -19,16 +19,17 @@ package org.apache.dolphinscheduler.dao.mapper;
 
 import org.apache.dolphinscheduler.common.enums.Flag;
 import org.apache.dolphinscheduler.common.enums.ReleaseState;
+import org.apache.dolphinscheduler.common.enums.WorkflowExecutionStatus;
 import org.apache.dolphinscheduler.dao.BaseDaoTest;
 import org.apache.dolphinscheduler.dao.entity.ExecuteStatusCount;
 import org.apache.dolphinscheduler.dao.entity.ProcessDefinition;
 import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
 import org.apache.dolphinscheduler.dao.entity.Project;
-import org.apache.dolphinscheduler.plugin.task.api.enums.ExecutionStatus;
 
 import java.util.Date;
 import java.util.List;
 
+import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 import org.junit.Assert;
 import org.junit.Test;
 import org.springframework.beans.factory.annotation.Autowired;
@@ -57,7 +58,7 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
         processInstance.setProcessDefinitionCode(1L);
         processInstance.setStartTime(start);
         processInstance.setEndTime(end);
-        processInstance.setState(ExecutionStatus.SUCCESS);
+        processInstance.setState(WorkflowExecutionStatus.SUCCESS);
 
         processInstanceMapper.insert(processInstance);
         return processInstance;
@@ -69,14 +70,14 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
      * @return ProcessInstance
      */
     private ProcessInstance insertOne() {
-        //insertOne
+        // insertOne
         ProcessInstance processInstance = new ProcessInstance();
         Date start = new Date(2019 - 1900, 1 - 1, 1, 0, 10, 0);
         Date end = new Date(2019 - 1900, 1 - 1, 1, 1, 0, 0);
         processInstance.setProcessDefinitionCode(1L);
         processInstance.setStartTime(start);
         processInstance.setEndTime(end);
-        processInstance.setState(ExecutionStatus.SUBMITTED_SUCCESS);
+        processInstance.setState(WorkflowExecutionStatus.SUBMITTED_SUCCESS);
 
         processInstanceMapper.insert(processInstance);
         return processInstance;
@@ -87,9 +88,9 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
      */
     @Test
     public void testUpdate() {
-        //insertOne
+        // insertOne
         ProcessInstance processInstanceMap = insertOne();
-        //update
+        // update
         int update = processInstanceMapper.updateById(processInstanceMap);
         Assert.assertEquals(1, update);
         processInstanceMapper.deleteById(processInstanceMap.getId());
@@ -111,7 +112,7 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
     @Test
     public void testQuery() {
         ProcessInstance processInstance = insertOne();
-        //query
+        // query
         List<ProcessInstance> dataSources = processInstanceMapper.selectList(null);
         Assert.assertNotEquals(dataSources.size(), 0);
         processInstanceMapper.deleteById(processInstance.getId());
@@ -137,12 +138,12 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
     public void testQueryByHostAndStates() {
         ProcessInstance processInstance = insertOne();
         processInstance.setHost("192.168.2.155");
-        processInstance.setState(ExecutionStatus.RUNNING_EXECUTION);
+        processInstance.setState(WorkflowExecutionStatus.RUNNING_EXECUTION);
         processInstanceMapper.updateById(processInstance);
 
         int[] stateArray = new int[]{
-                ExecutionStatus.RUNNING_EXECUTION.ordinal(),
-                ExecutionStatus.SUCCESS.ordinal()};
+                TaskExecutionStatus.RUNNING_EXECUTION.getCode(),
+                TaskExecutionStatus.SUCCESS.getCode()};
 
         List<ProcessInstance> processInstances = processInstanceMapper.queryByHostAndStatus(null, stateArray);
 
@@ -157,8 +158,8 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
     public void testQueryProcessInstanceListPaging() {
 
         int[] stateArray = new int[]{
-                ExecutionStatus.RUNNING_EXECUTION.ordinal(),
-                ExecutionStatus.SUCCESS.ordinal()};
+                WorkflowExecutionStatus.RUNNING_EXECUTION.getCode(),
+                WorkflowExecutionStatus.SUCCESS.getCode()};
 
         ProcessDefinition processDefinition = new ProcessDefinition();
         processDefinition.setCode(1L);
@@ -170,7 +171,7 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
 
         ProcessInstance processInstance = insertOne();
         processInstance.setProcessDefinitionCode(processDefinition.getCode());
-        processInstance.setState(ExecutionStatus.RUNNING_EXECUTION);
+        processInstance.setState(WorkflowExecutionStatus.RUNNING_EXECUTION);
         processInstance.setIsSubProcess(Flag.NO);
         processInstance.setStartTime(new Date());
 
@@ -187,8 +188,7 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
                 stateArray,
                 processInstance.getHost(),
                 null,
-                null
-        );
+                null);
         Assert.assertNotEquals(processInstanceIPage.getTotal(), 0);
 
         processDefinitionMapper.deleteById(processDefinition.getId());
@@ -202,12 +202,12 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
     public void testSetFailoverByHostAndStateArray() {
 
         int[] stateArray = new int[]{
-                ExecutionStatus.RUNNING_EXECUTION.ordinal(),
-                ExecutionStatus.SUCCESS.ordinal()};
+                WorkflowExecutionStatus.RUNNING_EXECUTION.ordinal(),
+                WorkflowExecutionStatus.SUCCESS.ordinal()};
 
         ProcessInstance processInstance = insertOne();
 
-        processInstance.setState(ExecutionStatus.RUNNING_EXECUTION);
+        processInstance.setState(WorkflowExecutionStatus.RUNNING_EXECUTION);
         processInstance.setHost("192.168.2.220");
         processInstanceMapper.updateById(processInstance);
         String host = processInstance.getHost();
@@ -227,14 +227,15 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
 
         ProcessInstance processInstance = insertOne();
 
-        processInstance.setState(ExecutionStatus.RUNNING_EXECUTION);
+        processInstance.setState(WorkflowExecutionStatus.RUNNING_EXECUTION);
         processInstanceMapper.updateById(processInstance);
-        processInstanceMapper.updateProcessInstanceByState(ExecutionStatus.RUNNING_EXECUTION, ExecutionStatus.SUCCESS);
+        processInstanceMapper.updateProcessInstanceByState(WorkflowExecutionStatus.RUNNING_EXECUTION,
+                WorkflowExecutionStatus.SUCCESS);
 
         ProcessInstance processInstance1 = processInstanceMapper.selectById(processInstance.getId());
 
         processInstanceMapper.deleteById(processInstance.getId());
-        Assert.assertEquals(ExecutionStatus.SUCCESS, processInstance1.getState());
+        Assert.assertEquals(WorkflowExecutionStatus.SUCCESS, processInstance1.getState());
 
     }
 
@@ -264,7 +265,8 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
 
         Long[] projectCodes = new Long[]{processDefinition.getProjectCode()};
 
-        List<ExecuteStatusCount> executeStatusCounts = processInstanceMapper.countInstanceStateByProjectCodes(null, null, projectCodes);
+        List<ExecuteStatusCount> executeStatusCounts =
+                processInstanceMapper.countInstanceStateByProjectCodes(null, null, projectCodes);
 
         Assert.assertNotEquals(executeStatusCounts.size(), 0);
 
@@ -281,10 +283,12 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
         ProcessInstance processInstance = insertOne();
         ProcessInstance processInstance1 = insertOne();
 
-        List<ProcessInstance> processInstances = processInstanceMapper.queryByProcessDefineCode(processInstance.getProcessDefinitionCode(), 1);
+        List<ProcessInstance> processInstances =
+                processInstanceMapper.queryByProcessDefineCode(processInstance.getProcessDefinitionCode(), 1);
         Assert.assertEquals(1, processInstances.size());
 
-        processInstances = processInstanceMapper.queryByProcessDefineCode(processInstance.getProcessDefinitionCode(), 2);
+        processInstances =
+                processInstanceMapper.queryByProcessDefineCode(processInstance.getProcessDefinitionCode(), 2);
         Assert.assertEquals(2, processInstances.size());
 
         processInstanceMapper.deleteById(processInstance.getId());
@@ -300,7 +304,8 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
         processInstance.setScheduleTime(new Date());
         processInstanceMapper.updateById(processInstance);
 
-        ProcessInstance processInstance1 = processInstanceMapper.queryLastSchedulerProcess(processInstance.getProcessDefinitionCode(), null, null);
+        ProcessInstance processInstance1 =
+                processInstanceMapper.queryLastSchedulerProcess(processInstance.getProcessDefinitionCode(), null, null);
         Assert.assertNotEquals(processInstance1, null);
         processInstanceMapper.deleteById(processInstance.getId());
     }
@@ -311,14 +316,15 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
     @Test
     public void testQueryLastRunningProcess() {
         ProcessInstance processInstance = insertOne();
-        processInstance.setState(ExecutionStatus.RUNNING_EXECUTION);
+        processInstance.setState(WorkflowExecutionStatus.RUNNING_EXECUTION);
         processInstanceMapper.updateById(processInstance);
 
         int[] stateArray = new int[]{
-                ExecutionStatus.RUNNING_EXECUTION.ordinal(),
-                ExecutionStatus.SUBMITTED_SUCCESS.ordinal()};
+                WorkflowExecutionStatus.RUNNING_EXECUTION.ordinal(),
+                WorkflowExecutionStatus.SUBMITTED_SUCCESS.ordinal()};
 
-        ProcessInstance processInstance1 = processInstanceMapper.queryLastRunningProcess(processInstance.getProcessDefinitionCode(), null, null, stateArray);
+        ProcessInstance processInstance1 = processInstanceMapper
+                .queryLastRunningProcess(processInstance.getProcessDefinitionCode(), null, null, stateArray);
 
         Assert.assertNotEquals(processInstance1, null);
         processInstanceMapper.deleteById(processInstance.getId());
@@ -334,13 +340,13 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
 
         Date start = new Date(2019 - 1900, 1 - 1, 01, 0, 0, 0);
         Date end = new Date(2019 - 1900, 1 - 1, 01, 5, 0, 0);
-        ProcessInstance processInstance1 = processInstanceMapper.queryLastManualProcess(processInstance.getProcessDefinitionCode(), start, end
-        );
+        ProcessInstance processInstance1 =
+                processInstanceMapper.queryLastManualProcess(processInstance.getProcessDefinitionCode(), start, end);
         Assert.assertEquals(processInstance1.getId(), processInstance.getId());
 
         start = new Date(2019 - 1900, 1 - 1, 01, 1, 0, 0);
-        processInstance1 = processInstanceMapper.queryLastManualProcess(processInstance.getProcessDefinitionCode(), start, end
-        );
+        processInstance1 =
+                processInstanceMapper.queryLastManualProcess(processInstance.getProcessDefinitionCode(), start, end);
         Assert.assertNull(processInstance1);
 
         processInstanceMapper.deleteById(processInstance.getId());
@@ -353,7 +359,8 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
     private boolean isSortedByDuration(List<ProcessInstance> processInstances) {
         for (int i = 1; i < processInstances.size(); i++) {
             long d1 = processInstances.get(i).getEndTime().getTime() - processInstances.get(i).getStartTime().getTime();
-            long d2 = processInstances.get(i - 1).getEndTime().getTime() - processInstances.get(i - 1).getStartTime().getTime();
+            long d2 = processInstances.get(i - 1).getEndTime().getTime()
+                    - processInstances.get(i - 1).getStartTime().getTime();
             if (d1 > d2) {
                 return false;
             }
@@ -377,11 +384,12 @@ public class ProcessInstanceMapperTest extends BaseDaoTest {
         ProcessInstance processInstance3 = insertOne(startTime3, endTime3);
         Date start = new Date(2020, 1, 1, 1, 1, 1);
         Date end = new Date(2021, 1, 1, 1, 1, 1);
-        List<ProcessInstance> processInstances = processInstanceMapper.queryTopNProcessInstance(2, start, end, ExecutionStatus.SUCCESS,0L);
+        List<ProcessInstance> processInstances =
+                processInstanceMapper.queryTopNProcessInstance(2, start, end, WorkflowExecutionStatus.SUCCESS, 0L);
         Assert.assertEquals(2, processInstances.size());
         Assert.assertTrue(isSortedByDuration(processInstances));
         for (ProcessInstance processInstance : processInstances) {
-            Assert.assertTrue(processInstance.getState().typeIsSuccess());
+            Assert.assertTrue(processInstance.getState().isSuccess());
         }
         processInstanceMapper.deleteById(processInstance1.getId());
         processInstanceMapper.deleteById(processInstance2.getId());
