@@ -22,6 +22,8 @@ import org.apache.dolphinscheduler.dao.entity.Project;
 import org.apache.dolphinscheduler.dao.entity.ProjectUser;
 import org.apache.dolphinscheduler.dao.entity.User;
 
+import java.util.Arrays;
+import java.util.Collections;
 import java.util.Date;
 import java.util.List;
 
@@ -145,14 +147,14 @@ public class ProjectMapperTest extends BaseDaoTest {
 
         Page<Project> page = new Page(1, 3);
         IPage<Project> projectIPage = projectMapper.queryProjectListPaging(
-                page,
-                project.getUserId(),
-                null
+            page,
+            null,
+            null
         );
         IPage<Project> projectIPage1 = projectMapper.queryProjectListPaging(
-                page,
-                project.getUserId(),
-                project.getName()
+            page,
+            null,
+            project.getName()
         );
         Assert.assertEquals(projectIPage.getTotal(), 1);
         Assert.assertEquals(projectIPage1.getTotal(), 1);
@@ -218,4 +220,15 @@ public class ProjectMapperTest extends BaseDaoTest {
 
         Assert.assertNotEquals(allProject.size(), 0);
     }
+
+    /**
+     * test query project permission
+     */
+    @Test
+    public void testListAuthorizedProjects() {
+        Project project = insertOne();
+        List<Project> projects = projectMapper.listAuthorizedProjects(1, Collections.singletonList(project.getId()));
+        Assert.assertEquals(projects.size(), 0);
+    }
+
 }
\ No newline at end of file
