@@ -55,7 +55,7 @@ public class ScheduleMapperTest extends BaseDaoTest {
      * @return Schedule
      */
     private Schedule insertOne() {
-        //insertOne
+        // insertOne
         Schedule schedule = new Schedule();
         schedule.setStartTime(new Date());
         schedule.setEndTime(new Date());
@@ -74,10 +74,10 @@ public class ScheduleMapperTest extends BaseDaoTest {
      */
     @Test
     public void testUpdate() {
-        //insertOne
+        // insertOne
         Schedule schedule = insertOne();
         schedule.setCreateTime(new Date());
-        //update
+        // update
         int update = scheduleMapper.updateById(schedule);
         Assert.assertEquals(update, 1);
     }
@@ -98,7 +98,7 @@ public class ScheduleMapperTest extends BaseDaoTest {
     @Test
     public void testQuery() {
         Schedule schedule = insertOne();
-        //query
+        // query
         List<Schedule> schedules = scheduleMapper.selectList(null);
         Assert.assertNotEquals(schedules.size(), 0);
     }
@@ -133,9 +133,9 @@ public class ScheduleMapperTest extends BaseDaoTest {
         Schedule schedule = insertOne();
         schedule.setUserId(user.getId());
         schedule.setProcessDefinitionCode(processDefinition.getCode());
-        scheduleMapper.insert(schedule);
+        scheduleMapper.updateById(schedule);
 
-        Page<Schedule> page = new Page(1,3);
+        Page<Schedule> page = new Page(1, 3);
         IPage<Schedule> scheduleIPage = scheduleMapper.queryByProcessDefineCodePaging(page,
                 processDefinition.getCode(), "");
         Assert.assertNotEquals(scheduleIPage.getSize(), 0);
@@ -171,12 +171,11 @@ public class ScheduleMapperTest extends BaseDaoTest {
         Schedule schedule = insertOne();
         schedule.setUserId(user.getId());
         schedule.setProcessDefinitionCode(processDefinition.getCode());
-        scheduleMapper.insert(schedule);
+        scheduleMapper.updateById(schedule);
 
-        Page<Schedule> page = new Page(1,3);
+        Page<Schedule> page = new Page(1, 3);
         List<Schedule> schedules = scheduleMapper.querySchedulerListByProjectName(
-                project.getName()
-        );
+                project.getName());
 
         Assert.assertNotEquals(schedules.size(), 0);
     }
@@ -192,7 +191,8 @@ public class ScheduleMapperTest extends BaseDaoTest {
         schedule.setReleaseState(ReleaseState.ONLINE);
         scheduleMapper.updateById(schedule);
 
-        List<Schedule> schedules = scheduleMapper.selectAllByProcessDefineArray(new long[] {schedule.getProcessDefinitionCode()});
+        List<Schedule> schedules =
+                scheduleMapper.selectAllByProcessDefineArray(new long[]{schedule.getProcessDefinitionCode()});
         Assert.assertNotEquals(schedules.size(), 0);
     }
 
