@@ -17,28 +17,24 @@
 
 package org.apache.dolphinscheduler.server.master;
 
-import org.apache.dolphinscheduler.common.Constants;
+import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.TimeoutFlag;
-import org.apache.dolphinscheduler.common.model.TaskNode;
-import org.apache.dolphinscheduler.common.thread.Stopper;
+import org.apache.dolphinscheduler.common.lifecycle.ServerLifeCycleManager;
+import org.apache.dolphinscheduler.common.enums.WorkflowExecutionStatus;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
 import org.apache.dolphinscheduler.plugin.task.api.enums.DependResult;
 import org.apache.dolphinscheduler.plugin.task.api.enums.DependentRelation;
-import org.apache.dolphinscheduler.plugin.task.api.enums.ExecutionStatus;
+import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 import org.apache.dolphinscheduler.plugin.task.api.model.DependentItem;
 import org.apache.dolphinscheduler.plugin.task.api.model.DependentTaskModel;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.DependentParameters;
 import org.apache.dolphinscheduler.server.master.config.MasterConfig;
 import org.apache.dolphinscheduler.service.bean.SpringApplicationContext;
+import org.apache.dolphinscheduler.service.model.TaskNode;
 import org.apache.dolphinscheduler.service.process.ProcessService;
-
-import java.time.Duration;
-import java.util.stream.Collectors;
-import java.util.stream.Stream;
-
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -46,6 +42,10 @@ import org.mockito.Mockito;
 import org.mockito.junit.MockitoJUnitRunner;
 import org.springframework.context.ApplicationContext;
 
+import java.time.Duration;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
+
 /**
  * DependentTaskTest
  */
@@ -57,7 +57,6 @@ public class DependentTaskTest {
      */
     public static final String FLOWNODE_RUN_FLAG_NORMAL = "NORMAL";
 
-
     public static final Long TASK_CODE = 1111L;
     public static final Long DEPEND_TASK_CODE_A = 110L;
     public static final Long DEPEND_TASK_CODE_B = 111L;
@@ -129,8 +128,7 @@ public class DependentTaskTest {
         DependentTaskModel dependentTaskModel = new DependentTaskModel();
         dependentTaskModel.setRelation(DependentRelation.AND);
         dependentTaskModel.setDependItemList(Stream.of(
-                getDependentItemFromTaskNode(2L, DEPEND_TASK_CODE_A, "today", "day")
-        ).collect(Collectors.toList()));
+                getDependentItemFromTaskNode(2L, DEPEND_TASK_CODE_A, "today", "day")).collect(Collectors.toList()));
 
         DependentParameters dependentParameters = new DependentParameters();
         dependentParameters.setRelation(DependentRelation.AND);
@@ -146,7 +144,7 @@ public class DependentTaskTest {
     public void testBasicSuccess() {
         testBasicInit();
         ProcessInstance dependentProcessInstance =
-                getProcessInstanceForFindLastRunningProcess(200, ExecutionStatus.FAILURE);
+                getProcessInstanceForFindLastRunningProcess(200, WorkflowExecutionStatus.FAILURE);
         // for DependentExecute.findLastProcessInterval
         Mockito.when(processService
                 .findLastRunningProcess(Mockito.eq(2L), Mockito.any(), Mockito.any()))
@@ -156,9 +154,11 @@ public class DependentTaskTest {
         Mockito.when(processService
                 .findValidTaskListByProcessId(200))
                 .thenReturn(Stream.of(
-                        getTaskInstanceForValidTaskList(2000, ExecutionStatus.SUCCESS, DEPEND_TASK_CODE_A, dependentProcessInstance),
-                        getTaskInstanceForValidTaskList(2000, ExecutionStatus.FAILURE, DEPEND_TASK_CODE_B, dependentProcessInstance)
-                ).collect(Collectors.toList()));
+                        getTaskInstanceForValidTaskList(2000, TaskExecutionStatus.SUCCESS, DEPEND_TASK_CODE_A,
+                                dependentProcessInstance),
+                        getTaskInstanceForValidTaskList(2000, TaskExecutionStatus.FAILURE, DEPEND_TASK_CODE_B,
+                                dependentProcessInstance))
+                        .collect(Collectors.toList()));
 
     }
 
@@ -166,7 +166,7 @@ public class DependentTaskTest {
     public void testBasicFailure() {
         testBasicInit();
         ProcessInstance dependentProcessInstance =
-                getProcessInstanceForFindLastRunningProcess(200, ExecutionStatus.SUCCESS);
+                getProcessInstanceForFindLastRunningProcess(200, WorkflowExecutionStatus.SUCCESS);
         // for DependentExecute.findLastProcessInterval
         Mockito.when(processService
                 .findLastRunningProcess(Mockito.eq(2L), Mockito.any(), Mockito.any()))
@@ -176,9 +176,11 @@ public class DependentTaskTest {
         Mockito.when(processService
                 .findValidTaskListByProcessId(200))
                 .thenReturn(Stream.of(
-                        getTaskInstanceForValidTaskList(2000, ExecutionStatus.FAILURE, DEPEND_TASK_CODE_A, dependentProcessInstance),
-                        getTaskInstanceForValidTaskList(2000, ExecutionStatus.SUCCESS, DEPEND_TASK_CODE_B, dependentProcessInstance)
-                ).collect(Collectors.toList()));
+                        getTaskInstanceForValidTaskList(2000, TaskExecutionStatus.FAILURE, DEPEND_TASK_CODE_A,
+                                dependentProcessInstance),
+                        getTaskInstanceForValidTaskList(2000, TaskExecutionStatus.SUCCESS, DEPEND_TASK_CODE_B,
+                                dependentProcessInstance))
+                        .collect(Collectors.toList()));
     }
 
     @Test
@@ -187,35 +189,31 @@ public class DependentTaskTest {
         dependentTaskModel1.setRelation(DependentRelation.AND);
         dependentTaskModel1.setDependItemList(Stream.of(
                 getDependentItemFromTaskNode(2L, DEPEND_TASK_CODE_A, "today", "day"),
-                getDependentItemFromTaskNode(3L, DEPEND_TASK_CODE_B, "today", "day")
-        ).collect(Collectors.toList()));
+                getDependentItemFromTaskNode(3L, DEPEND_TASK_CODE_B, "today", "day")).collect(Collectors.toList()));
 
         DependentTaskModel dependentTaskModel2 = new DependentTaskModel();
         dependentTaskModel2.setRelation(DependentRelation.OR);
         dependentTaskModel2.setDependItemList(Stream.of(
                 getDependentItemFromTaskNode(2L, DEPEND_TASK_CODE_A, "today", "day"),
-                getDependentItemFromTaskNode(3L, DEPEND_TASK_CODE_C, "today", "day")
-        ).collect(Collectors.toList()));
+                getDependentItemFromTaskNode(3L, DEPEND_TASK_CODE_C, "today", "day")).collect(Collectors.toList()));
 
         /*
-         * OR   AND 2-A-day-today 3-B-day-today
-         *      OR  2-A-day-today 3-C-day-today
+         * OR AND 2-A-day-today 3-B-day-today OR 2-A-day-today 3-C-day-today
          */
         DependentParameters dependentParameters = new DependentParameters();
         dependentParameters.setRelation(DependentRelation.OR);
         dependentParameters.setDependTaskList(Stream.of(
                 dependentTaskModel1,
-                dependentTaskModel2
-        ).collect(Collectors.toList()));
+                dependentTaskModel2).collect(Collectors.toList()));
 
         TaskNode taskNode = getDependantTaskNode();
         taskNode.setDependence(JSONUtils.toJsonString(dependentParameters));
         setupTaskInstance(taskNode);
 
         ProcessInstance processInstance200 =
-                getProcessInstanceForFindLastRunningProcess(200, ExecutionStatus.FAILURE);
+                getProcessInstanceForFindLastRunningProcess(200, WorkflowExecutionStatus.FAILURE);
         ProcessInstance processInstance300 =
-                getProcessInstanceForFindLastRunningProcess(300, ExecutionStatus.SUCCESS);
+                getProcessInstanceForFindLastRunningProcess(300, WorkflowExecutionStatus.SUCCESS);
 
         // for DependentExecute.findLastProcessInterval
         Mockito.when(processService
@@ -229,18 +227,21 @@ public class DependentTaskTest {
         Mockito.when(processService
                 .findValidTaskListByProcessId(200))
                 .thenReturn(Stream.of(
-                        getTaskInstanceForValidTaskList(2000, ExecutionStatus.FAILURE, DEPEND_TASK_CODE_A, processInstance200)
-                ).collect(Collectors.toList()));
+                        getTaskInstanceForValidTaskList(2000, TaskExecutionStatus.FAILURE, DEPEND_TASK_CODE_A,
+                                processInstance200))
+                        .collect(Collectors.toList()));
         Mockito.when(processService
                 .findValidTaskListByProcessId(300))
                 .thenReturn(Stream.of(
-                        getTaskInstanceForValidTaskList(3000, ExecutionStatus.SUCCESS, DEPEND_TASK_CODE_B, processInstance300),
-                        getTaskInstanceForValidTaskList(3001, ExecutionStatus.SUCCESS, DEPEND_TASK_CODE_C, processInstance300)
-                ).collect(Collectors.toList()));
+                        getTaskInstanceForValidTaskList(3000, TaskExecutionStatus.SUCCESS, DEPEND_TASK_CODE_B,
+                                processInstance300),
+                        getTaskInstanceForValidTaskList(3001, TaskExecutionStatus.SUCCESS, DEPEND_TASK_CODE_C,
+                                processInstance300))
+                        .collect(Collectors.toList()));
 
-        //DependentTaskExecThread taskExecThread = new DependentTaskExecThread(taskInstance);
-        //taskExecThread.call();
-        //Assert.assertEquals(ExecutionStatus.SUCCESS, taskExecThread.getTaskInstance().getState());
+        // DependentTaskExecThread taskExecThread = new DependentTaskExecThread(taskInstance);
+        // taskExecThread.call();
+        // Assert.assertEquals(ExecutionStatus.SUCCESS, taskExecThread.getTaskInstance().getState());
     }
 
     /**
@@ -251,8 +252,8 @@ public class DependentTaskTest {
         DependentTaskModel dependentTaskModel = new DependentTaskModel();
         dependentTaskModel.setRelation(DependentRelation.AND);
         dependentTaskModel.setDependItemList(Stream.of(
-                getDependentItemFromTaskNode(2L, Constants.DEPENDENT_ALL_TASK_CODE, "today", "day")
-        ).collect(Collectors.toList()));
+                getDependentItemFromTaskNode(2L, Constants.DEPENDENT_ALL_TASK_CODE, "today", "day"))
+                .collect(Collectors.toList()));
 
         DependentParameters dependentParameters = new DependentParameters();
         dependentParameters.setRelation(DependentRelation.AND);
@@ -270,11 +271,11 @@ public class DependentTaskTest {
         // for DependentExecute.findLastProcessInterval
         Mockito.when(processService
                 .findLastRunningProcess(Mockito.eq(2L), Mockito.any(), Mockito.any()))
-                .thenReturn(getProcessInstanceForFindLastRunningProcess(200, ExecutionStatus.SUCCESS));
+                .thenReturn(getProcessInstanceForFindLastRunningProcess(200, WorkflowExecutionStatus.SUCCESS));
 
-        //DependentTaskExecThread taskExecThread = new DependentTaskExecThread(taskInstance);
-        //taskExecThread.call();
-        //Assert.assertEquals(ExecutionStatus.SUCCESS, taskExecThread.getTaskInstance().getState());
+        // DependentTaskExecThread taskExecThread = new DependentTaskExecThread(taskInstance);
+        // taskExecThread.call();
+        // Assert.assertEquals(ExecutionStatus.SUCCESS, taskExecThread.getTaskInstance().getState());
     }
 
     @Test
@@ -283,11 +284,11 @@ public class DependentTaskTest {
         // for DependentExecute.findLastProcessInterval
         Mockito.when(processService
                 .findLastRunningProcess(Mockito.eq(2L), Mockito.any(), Mockito.any()))
-                .thenReturn(getProcessInstanceForFindLastRunningProcess(200, ExecutionStatus.FAILURE));
+                .thenReturn(getProcessInstanceForFindLastRunningProcess(200, WorkflowExecutionStatus.FAILURE));
 
-        //DependentTaskExecThread dependentTask = new DependentTaskExecThread(taskInstance);
-        //dependentTask.call();
-        //Assert.assertEquals(ExecutionStatus.FAILURE, dependentTask.getTaskInstance().getState());
+        // DependentTaskExecThread dependentTask = new DependentTaskExecThread(taskInstance);
+        // dependentTask.call();
+        // Assert.assertEquals(ExecutionStatus.FAILURE, dependentTask.getTaskInstance().getState());
     }
 
     /**
@@ -296,7 +297,7 @@ public class DependentTaskTest {
     @Test
     public void testWaitAndCancel() {
         // for the poor independence of UT, error on other place may causes the condition happens
-        if (!Stopper.isRunning()) {
+        if (!ServerLifeCycleManager.isRunning()) {
             return;
         }
 
@@ -304,8 +305,7 @@ public class DependentTaskTest {
         DependentTaskModel dependentTaskModel = new DependentTaskModel();
         dependentTaskModel.setRelation(DependentRelation.AND);
         dependentTaskModel.setDependItemList(Stream.of(
-                getDependentItemFromTaskNode(2L, DEPEND_TASK_CODE_A, "today", "day")
-        ).collect(Collectors.toList()));
+                getDependentItemFromTaskNode(2L, DEPEND_TASK_CODE_A, "today", "day")).collect(Collectors.toList()));
 
         DependentParameters dependentParameters = new DependentParameters();
         dependentParameters.setRelation(DependentRelation.AND);
@@ -317,33 +317,34 @@ public class DependentTaskTest {
         setupTaskInstance(taskNode);
 
         ProcessInstance dependentProcessInstance =
-                getProcessInstanceForFindLastRunningProcess(200, ExecutionStatus.RUNNING_EXECUTION);
+                getProcessInstanceForFindLastRunningProcess(200, WorkflowExecutionStatus.RUNNING_EXECUTION);
         // for DependentExecute.findLastProcessInterval
         Mockito.when(processService
                 .findLastRunningProcess(Mockito.eq(2L), Mockito.any(), Mockito.any()))
                 .thenReturn(dependentProcessInstance);
 
-        //DependentTaskExecThread taskExecThread = new DependentTaskExecThread(taskInstance);
+        // DependentTaskExecThread taskExecThread = new DependentTaskExecThread(taskInstance);
 
         // for DependentExecute.getDependTaskResult
         Mockito.when(processService
                 .findValidTaskListByProcessId(200))
                 .thenAnswer(i -> {
-                    processInstance.setState(ExecutionStatus.READY_STOP);
+                    processInstance.setState(WorkflowExecutionStatus.READY_STOP);
                     return Stream.of(
-                            getTaskInstanceForValidTaskList(2000, ExecutionStatus.RUNNING_EXECUTION, DEPEND_TASK_CODE_A, dependentProcessInstance)
-                    ).collect(Collectors.toList());
+                            getTaskInstanceForValidTaskList(2000, TaskExecutionStatus.RUNNING_EXECUTION,
+                                    DEPEND_TASK_CODE_A, dependentProcessInstance))
+                            .collect(Collectors.toList());
                 })
                 .thenThrow(new IllegalStateException("have not been stopped as expected"));
 
-        //taskExecThread.call();
-        //Assert.assertEquals(ExecutionStatus.KILL, taskExecThread.getTaskInstance().getState());
+        // taskExecThread.call();
+        // Assert.assertEquals(ExecutionStatus.KILL, taskExecThread.getTaskInstance().getState());
     }
 
     private ProcessInstance getProcessInstance() {
         ProcessInstance processInstance = new ProcessInstance();
         processInstance.setId(100);
-        processInstance.setState(ExecutionStatus.RUNNING_EXECUTION);
+        processInstance.setState(WorkflowExecutionStatus.RUNNING_EXECUTION);
         return processInstance;
     }
 
@@ -382,7 +383,7 @@ public class DependentTaskTest {
         taskInstance.setTaskCode(TASK_CODE);
         taskInstance.setTaskDefinitionVersion(TASK_VERSION);
         taskInstance.setProcessInstanceId(processInstance.getId());
-        taskInstance.setState(ExecutionStatus.SUBMITTED_SUCCESS);
+        taskInstance.setState(TaskExecutionStatus.SUBMITTED_SUCCESS);
         taskInstance.setTaskType(taskNode.getType().toUpperCase());
         taskInstance.setDependency(JSONUtils.parseObject(taskNode.getDependence(), DependentParameters.class));
         taskInstance.setName(taskNode.getName());
@@ -391,7 +392,8 @@ public class DependentTaskTest {
     /**
      * DependentItem defines the condition for the dependent
      */
-    private DependentItem getDependentItemFromTaskNode(Long processDefinitionCode, long taskCode, String date, String cycle) {
+    private DependentItem getDependentItemFromTaskNode(Long processDefinitionCode, long taskCode, String date,
+                                                       String cycle) {
         DependentItem dependentItem = new DependentItem();
         dependentItem.setDefinitionCode(processDefinitionCode);
         dependentItem.setDepTaskCode(taskCode);
@@ -399,11 +401,12 @@ public class DependentTaskTest {
         dependentItem.setCycle(cycle);
         // so far, the following fields have no effect
         dependentItem.setDependResult(DependResult.SUCCESS);
-        dependentItem.setStatus(ExecutionStatus.SUCCESS);
+        dependentItem.setStatus(TaskExecutionStatus.SUCCESS);
         return dependentItem;
     }
 
-    private ProcessInstance getProcessInstanceForFindLastRunningProcess(int processInstanceId, ExecutionStatus state) {
+    private ProcessInstance getProcessInstanceForFindLastRunningProcess(int processInstanceId,
+                                                                        WorkflowExecutionStatus state) {
         ProcessInstance processInstance = new ProcessInstance();
         processInstance.setId(processInstanceId);
         processInstance.setState(state);
@@ -411,9 +414,8 @@ public class DependentTaskTest {
     }
 
     private TaskInstance getTaskInstanceForValidTaskList(
-            int taskInstanceId, ExecutionStatus state,
-            long taskCode, ProcessInstance processInstance
-    ) {
+                                                         int taskInstanceId, TaskExecutionStatus state,
+                                                         long taskCode, ProcessInstance processInstance) {
         TaskInstance taskInstance = new TaskInstance();
         taskInstance.setTaskType("DEPENDENT");
         taskInstance.setId(taskInstanceId);
