@@ -17,6 +17,8 @@
 
 package org.apache.dolphinscheduler.remote.command;
 
+import lombok.AllArgsConstructor;
+import lombok.Data;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 
 import java.io.Serializable;
@@ -24,35 +26,11 @@ import java.io.Serializable;
 /**
  * db task final result response command
  */
+@Data
+@AllArgsConstructor
 public class StateEventResponseCommand implements Serializable {
 
     private String key;
-    private int status;
-
-    public StateEventResponseCommand() {
-        super();
-    }
-
-    public StateEventResponseCommand(int status, String key) {
-        this.status = status;
-        this.key = key;
-    }
-
-    public int getStatus() {
-        return status;
-    }
-
-    public void setStatus(int status) {
-        this.status = status;
-    }
-
-    public String getKey() {
-        return key;
-    }
-
-    public void setKey(String key) {
-        this.key = key;
-    }
 
     /**
      * package response command
@@ -67,12 +45,4 @@ public class StateEventResponseCommand implements Serializable {
         return command;
     }
 
-    @Override
-    public String toString() {
-        return "StateEventResponseCommand{"
-                + "key=" + key
-                + ", status=" + status
-                + '}';
-    }
-
 }
