@@ -17,7 +17,12 @@
 
 package org.apache.dolphinscheduler.remote.command;
 
+import lombok.AllArgsConstructor;
+import lombok.Builder;
+import lombok.Data;
+import lombok.NoArgsConstructor;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
+import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 
 import java.io.Serializable;
 import java.util.List;
@@ -25,27 +30,18 @@ import java.util.List;
 /**
  * kill task response command
  */
+@Data
+@Builder
+@NoArgsConstructor
+@AllArgsConstructor
 public class TaskKillResponseCommand implements Serializable {
 
-    /**
-     * taskInstanceId
-     */
     private int taskInstanceId;
 
-    /**
-     * host
-     */
     private String host;
 
-    /**
-     * status
-     */
-    private int status;
+    private TaskExecutionStatus status;
 
-
-    /**
-     * processId
-     */
     private int processId;
 
     /**
@@ -53,46 +49,6 @@ public class TaskKillResponseCommand implements Serializable {
      */
     private List<String> appIds;
 
-    public int getTaskInstanceId() {
-        return taskInstanceId;
-    }
-
-    public void setTaskInstanceId(int taskInstanceId) {
-        this.taskInstanceId = taskInstanceId;
-    }
-
-    public String getHost() {
-        return host;
-    }
-
-    public void setHost(String host) {
-        this.host = host;
-    }
-
-    public int getStatus() {
-        return status;
-    }
-
-    public void setStatus(int status) {
-        this.status = status;
-    }
-
-    public int getProcessId() {
-        return processId;
-    }
-
-    public void setProcessId(int processId) {
-        this.processId = processId;
-    }
-
-    public List<String> getAppIds() {
-        return appIds;
-    }
-
-    public void setAppIds(List<String> appIds) {
-        this.appIds = appIds;
-    }
-
     /**
      * package request command
      *
@@ -106,14 +62,4 @@ public class TaskKillResponseCommand implements Serializable {
         return command;
     }
 
-    @Override
-    public String toString() {
-        return "TaskKillResponseCommand{"
-                + "taskInstanceId=" + taskInstanceId
-                + ", host='" + host + '\''
-                + ", status=" + status
-                + ", processId=" + processId
-                + ", appIds=" + appIds
-                + '}';
-    }
 }
