@@ -18,8 +18,15 @@
 package org.apache.dolphinscheduler.plugin.task.api;
 
 import org.apache.dolphinscheduler.spi.common.UiChannelFactory;
+import org.apache.dolphinscheduler.spi.plugin.SPIIdentify;
+import org.apache.dolphinscheduler.spi.plugin.PrioritySPI;
 
-public interface TaskChannelFactory extends UiChannelFactory {
+public interface TaskChannelFactory extends UiChannelFactory, PrioritySPI {
 
     TaskChannel create();
+
+    default SPIIdentify getIdentify() {
+        return SPIIdentify.builder().name(getName()).build();
+    }
+
 }
