@@ -26,6 +26,8 @@ public class Constants {
     public static final String CONFIG_OPTIONS = "--config";
     public static final String DEPLOY_MODE_OPTIONS = "--deploy-mode";
     public static final String MASTER_OPTIONS = "--master";
-    public static final String QUEUE_OPTIONS = "--queue";
+    public static final String STARTUP_SCRIPT_SPARK = "spark";
+    public static final String STARTUP_SCRIPT_FLINK = "flink";
+    public static final String STARTUP_SCRIPT_SEATUNNEL = "seatunnel";
 
 }
