@@ -23,6 +23,7 @@ export const useUserStore = defineStore({
   id: 'user',
   state: (): UserState => ({
     sessionId: '',
+    securityConfigType: '',
     userInfo: {}
   }),
   persist: true,
@@ -30,6 +31,9 @@ export const useUserStore = defineStore({
     getSessionId(): string {
       return this.sessionId
     },
+    getSecurityConfigType(): string {
+      return this.securityConfigType
+    },
     getUserInfo(): UserInfoRes | {} {
       return this.userInfo
     }
@@ -38,6 +42,9 @@ export const useUserStore = defineStore({
     setSessionId(sessionId: string): void {
       this.sessionId = sessionId
     },
+    setSecurityConfigType(securityConfigType: string): void {
+      this.securityConfigType = securityConfigType
+    },
     setUserInfo(userInfo: UserInfoRes | {}): void {
       this.userInfo = userInfo
     }
