@@ -15,7 +15,13 @@
  * limitations under the License.
  */
 
-import { defineComponent, PropType, toRefs, watch } from 'vue'
+import {
+  defineComponent,
+  getCurrentInstance,
+  PropType,
+  toRefs,
+  watch
+} from 'vue'
 import {
   NButton,
   NSpin,
@@ -84,15 +90,17 @@ const DetailModal = defineComponent({
     const onChangeType = changeType
     const onChangePort = changePort
 
+    const trim = getCurrentInstance()?.appContext.config.globalProperties.trim
+
     watch(
       () => props.show,
       async () => {
         props.show &&
           state.detailForm.type &&
-          await changeType(
+          (await changeType(
             state.detailForm.type,
             datasourceType[state.detailForm.type]
-          )
+          ))
         props.show && props.id && setFieldsValue(await queryById(props.id))
       }
     )
@@ -105,7 +113,8 @@ const DetailModal = defineComponent({
       onChangePort,
       onSubmit,
       onTest,
-      onCancel
+      onCancel,
+      trim
     }
   },
   render() {
@@ -116,6 +125,9 @@ const DetailModal = defineComponent({
       detailForm,
       rules,
       requiredDataBase,
+      showHost,
+      showPort,
+      showAwsRegion,
       showConnectType,
       showPrincipal,
       loading,
@@ -168,6 +180,7 @@ const DetailModal = defineComponent({
                   show-require-mark
                 >
                   <NInput
+                    allowInput={this.trim}
                     class='input-data-source-name'
                     v-model={[detailForm.name, 'value']}
                     maxlength={60}
@@ -176,6 +189,7 @@ const DetailModal = defineComponent({
                 </NFormItem>
                 <NFormItem label={t('datasource.description')} path='note'>
                   <NInput
+                    allowInput={this.trim}
                     class='input-data-source-description'
                     v-model={[detailForm.note, 'value']}
                     type='textarea'
@@ -183,11 +197,13 @@ const DetailModal = defineComponent({
                   />
                 </NFormItem>
                 <NFormItem
+                  v-show={showHost}
                   label={t('datasource.ip')}
                   path='host'
                   show-require-mark
                 >
                   <NInput
+                    allowInput={this.trim}
                     class='input-ip'
                     v-model={[detailForm.host, 'value']}
                     type='text'
@@ -196,6 +212,7 @@ const DetailModal = defineComponent({
                   />
                 </NFormItem>
                 <NFormItem
+                  v-show={showPort}
                   label={t('datasource.port')}
                   path='port'
                   show-require-mark
@@ -216,6 +233,7 @@ const DetailModal = defineComponent({
                   show-require-mark
                 >
                   <NInput
+                    allowInput={this.trim}
                     v-model={[detailForm.principal, 'value']}
                     type='text'
                     placeholder={t('datasource.principal_tips')}
@@ -227,6 +245,7 @@ const DetailModal = defineComponent({
                   path='javaSecurityKrb5Conf'
                 >
                   <NInput
+                    allowInput={this.trim}
                     v-model={[detailForm.javaSecurityKrb5Conf, 'value']}
                     type='text'
                     placeholder={t('datasource.krb5_conf_tips')}
@@ -238,6 +257,7 @@ const DetailModal = defineComponent({
                   path='loginUserKeytabUsername'
                 >
                   <NInput
+                    allowInput={this.trim}
                     v-model={[detailForm.loginUserKeytabUsername, 'value']}
                     type='text'
                     placeholder={t('datasource.keytab_username_tips')}
@@ -249,6 +269,7 @@ const DetailModal = defineComponent({
                   path='loginUserKeytabPath'
                 >
                   <NInput
+                    allowInput={this.trim}
                     v-model={[detailForm.loginUserKeytabPath, 'value']}
                     type='text'
                     placeholder={t('datasource.keytab_path_tips')}
@@ -260,6 +281,7 @@ const DetailModal = defineComponent({
                   show-require-mark
                 >
                   <NInput
+                    allowInput={this.trim}
                     class='input-username'
                     v-model={[detailForm.userName, 'value']}
                     type='text'
@@ -272,18 +294,34 @@ const DetailModal = defineComponent({
                   path='password'
                 >
                   <NInput
+                    allowInput={this.trim}
                     class='input-password'
                     v-model={[detailForm.password, 'value']}
                     type='password'
                     placeholder={t('datasource.user_password_tips')}
                   />
                 </NFormItem>
+                <NFormItem
+                    v-show={showAwsRegion}
+                    label={t('datasource.aws_region')}
+                    path='awsRegion'
+                    show-require-mark
+                >
+                  <NInput
+                      allowInput={this.trim}
+                      v-model={[detailForm.awsRegion, 'value']}
+                      type='text'
+                      maxlength={60}
+                      placeholder={t('datasource.aws_region_tips')}
+                  />
+                </NFormItem>
                 <NFormItem
                   label={t('datasource.database_name')}
                   path='database'
                   show-require-mark={requiredDataBase}
                 >
                   <NInput
+                    allowInput={this.trim}
                     class='input-data-base'
                     v-model={[detailForm.database, 'value']}
                     type='text'
@@ -313,6 +351,7 @@ const DetailModal = defineComponent({
                   path='other'
                 >
                   <NInput
+                    allowInput={this.trim}
                     class='input-jdbc-params'
                     v-model={[detailForm.other, 'value']}
                     type='textarea'
