@@ -46,7 +46,7 @@ export function useSeaTunnel({
     memoryMax: -1,
     delayTime: 0,
     timeout: 30,
-    engine: 'FLINK',
+    startupScript: 'seatunnel.sh',
     runMode: 'RUN',
     useCustom: true,
     deployMode: 'client',
@@ -56,25 +56,29 @@ export function useSeaTunnel({
     timeoutNotifyStrategy: ['WARN'],
     rawScript:
       'env {\n' +
-      '    execution.parallelism = 1\n' +
-      '}\n' +
-      '\n' +
-      'source {\n' +
-      '    FakeSourceStream {\n' +
-      '        result_table_name = "fake"\n' +
-      '        field_name = "name,age"\n' +
-      '    }\n' +
-      '}\n' +
-      '\n' +
-      'transform {\n' +
-      '    sql {\n' +
-      '        sql = "select name,age from fake"\n' +
-      '    }\n' +
-      '}\n' +
-      '\n' +
-      'sink {\n' +
-      '    ConsoleSink {}\n' +
-      '}'
+        '  execution.parallelism = 2\n' +
+        '  job.mode = "BATCH"\n' +
+        '  checkpoint.interval = 10000\n' +
+        '}\n' +
+        '\n' +
+        'source {\n' +
+        '  FakeSource {\n' +
+        '    parallelism = 2\n' +
+        '    result_table_name = "fake"\n' +
+        '    row.num = 16\n' +
+        '    schema = {\n' +
+        '      fields {\n' +
+        '        name = "string"\n' +
+        '        age = "int"\n' +
+        '      }\n' +
+        '    }\n' +
+        '  }\n' +
+        '}\n' +
+        '\n' +
+        'sink {\n' +
+        '  Console {\n' +
+        '  }\n' +
+        '}'
   } as INodeData)
 
   return {
@@ -85,7 +89,7 @@ export function useSeaTunnel({
       Fields.useDescription(),
       Fields.useTaskPriority(),
       Fields.useWorkerGroup(),
-      Fields.useEnvironmentName(model, !model.id),
+      Fields.useEnvironmentName(model, !data?.id),
       ...Fields.useTaskGroup(model, projectCode),
       ...Fields.useFailed(),
       ...Fields.useResourceLimit(),
