@@ -51,7 +51,8 @@ export const useForm = () => {
     startForm: {
       processDefinitionCode: -1,
       startEndTime: [new Date(year, month, day), new Date(year, month, day)],
-      scheduleTime: null,
+      scheduleTime: '',
+      dataDateType: 1,
       failureStrategy: 'CONTINUE',
       warningType: 'NONE',
       warningGroupId: null,
@@ -67,14 +68,33 @@ export const useForm = () => {
       expectedParallelismNumber: '',
       dryRun: 0
     },
-    saving: false
+    saving: false,
+    rules: {
+      scheduleTime: {
+        trigger: ['input', 'blur'],
+        validator(unuse: any, value: string) {
+          if (!value) return
+          if (
+            !/(((19|20)[0-9]{2})-((0[1-9])|(1[0-2]))-((0[1-9])|((1|2)[0-9])|(3[0-1]))([ ])([0-1]?[0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]))(,(((19|20)[0-9]{2})-((0[1-9])|(1[0-2]))-((0[1-9])|((1|2)[0-9])|(3[0-1]))([ ])([0-1]?[0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9])))*$/.test(
+              value
+            )
+          ) {
+            return new Error(t('project.workflow.schedule_date_tips'))
+          }
+          const dates = value.split(',')
+          if (dates.length > 100) {
+            return new Error(t('project.workflow.schedule_date_limit'))
+          }
+        }
+      }
+    }
   })
 
   const timingState = reactive({
     timingFormRef: ref(),
     timingForm: {
       startEndTime: [
-        new Date(year, month, day + 1),
+        new Date(year, month, day),
         new Date(year + 100, month, day)
       ],
       crontab: '0 0 * * * ? *',
